@@ -6,7 +6,7 @@ use Carp;
 use FabForce::DBDesigner4::XML;
 use FabForce::DBDesigner4::SQL;
 
-our $VERSION     = '0.14';
+our $VERSION     = '0.31';
 
 sub new{
   my ($class,%args) = @_;
@@ -22,33 +22,18 @@ sub new{
 
 sub parsefile{
   my ($self,%args) = @_;
-
-  croak "only one filetype" if(defined $args{sql} and defined $args{xml});
-  $self->{sql} = $args{sql} if(defined $args{sql});
+  
   $self->{xml} = $args{xml} if(defined $args{xml});
 
-  if(defined $self->{sql}){
-    my $sql = FabForce::DBDesigner4::SQL->new();
-    $self->{structure} = $sql->parsefile($self->{sql});
-  }
-  elsif(defined $self->{xml}){
-    my $xml = FabForce::DBDesigner4::XML->new();
-    $self->{structure} = $xml->parsefile($self->{xml});
+  if( defined $self->{xml} ) {
+    my $xml = FabForce::DBDesigner4::XML->new;
+    $self->{structure} = $xml->parsefile( $self->{xml} );
   }
   else{
-    croak "No inputfile defined!"
+    croak "No valid filetype defined!"
   }
 }# parsefile
 
-sub writeXML{
-  my ($self,$filename,$args) = @_;
-  
-  my $xml           = FabForce::DBDesigner4::XML->new();
-  my $structForFile = (delete $args->{struct}) || $self->{structure} || '';
-  
-  $xml->writeXML($structForFile,$filename);
-}# writeXML
-
 sub writeSQL{
   my ($self,$filename,$args) = @_;
   
@@ -77,12 +62,17 @@ sub getSQL{
 
 1;
 
-__END__
 
 
+=pod
+
 =head1 NAME
 
-FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
+FabForce::DBDesigner4
+
+=head1 VERSION
+
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -90,7 +80,6 @@ FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForc
 
   my $designer = FabForce::DBDesigner4->new();
   $designer->parsefile(xml => 'KESS.xml');
-  $designer->writeXML('text_xml.xml');
   $designer->writeSQL('text_sql.sql',{ type => 'mysql' });
 
 =head1 DESCRIPTION
@@ -99,39 +88,36 @@ FabForce::DBDesigner4 is a module to analyse xml-files created
 by the Database-Design tool DBDesigner (Version 4) from
 FabForce (http://www.fabforce.net).
 
+B<NOTICE>: As of version 0.2 you can not parse sql files any longer. You just
+can parse xml files created by DBDesigner. And you can't create XML files!
 
-You can also parse simple .sql-files to get the table structures
-off CREATE-statements.
+=head1 NAME
+
+FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
 
 =head1 METHODS
 
-
 =head2 new
 
   # create a new instance
   my $designer = FabForce::DBDesigner4->new();
-  
+
 =head2 parsefile
 
-parse the input file (either SQL or XML (FabForce-format))
+parse the input file (XML - FabForce format )
 
   # parse a xml-file
   $designer->parsefile(xml => 'KESS.xml');
-  # parse a sql-file
-  $designer->parsefile(sql => 'database.sql');
-  
-=head2 writeXML
 
-prints the structure into a xml-file (FabForce-format)
-
-  $designer->writeXML('foo.xml');
-  
 =head2 writeSQL
 
 print the structure into a sql-file
 
   $designer->writeSQL('foo.sql');
   
+  # print "drop table statements"
+  $designer->writeSQL( 'foo.sql', { drop_tables => 1 } );
+
 =head2 getTables
 
 returns an array of table-objects
@@ -143,6 +129,9 @@ returns an array of table-objects
 returns an array of CREATE statements. One element for each table.
 
   my @creates = $designer->getSQL();
+  
+  # get "drop table" statements in extra elements
+  my @creates = $designer->getSQL({ drop_table => 1 });
 
 =head1 DBDesigner4::Table
 
@@ -157,7 +146,7 @@ Methods of the table-objects
   $table->name('tablename');
   # get the tablename
   my $name = $table->name();
-  
+
 =head2 columns
 
   # set the tablecolumns
@@ -166,17 +155,17 @@ Methods of the table-objects
   
   # get the columns
   print $_,"\n" for($table->columns());
-  
+
 =head2 columnType
 
   # get datatype of n-th column (i.e. 3rd column)
   my $datatype = $table->columnType(3);
-  
+
 =head2 columnInfo
 
   # get info about n-th column (i.e. 4th column)
   print Dumper($table->columnInfo(4));
-  
+
 =head2 stringsToTableCols
 
   # maps column information to hash (needed for columns())
@@ -188,7 +177,7 @@ Methods of the table-objects
   # add the tablecolumn
   my $column = ['column1','int','not null'];
   $table->addColumn($column);
-  
+
 =head2 relations
 
   # set relations
@@ -200,7 +189,7 @@ Methods of the table-objects
 =head2 addRelation
 
   $table->addRelation([1,'startTable.startCol','targetTable.targetCol']);
-  
+
 =head2 removeRelation
 
   # removes a relation (i.e. 2nd relation)
@@ -216,7 +205,7 @@ Methods of the table-objects
 
 =head1 DEPENDENCIES
 
-This module requires XML::Twig, XML::Writer and IO::File
+This module requires XML::Twig
 
 =head1 BUGS and COMMENTS
 
@@ -225,9 +214,7 @@ bugreports or comments on this module.
 
 =head1 SEE ALSO
 
-  XML::Twig
-  XML::Writer
-  IO::File
+  XML::Twig and IO::File
 
 =head1 AUTHOR
 
@@ -235,11 +222,28 @@ Renee Baecker, E<lt>module@renee-baecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Renee Baecker
+Copyright (C) 2005 - 2011 by Renee Baecker
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.6.1 or,
-at your option, any later version of Perl 5 you may have available.
+This program is free software; you can redistribute it and/or
+modify it under the terms of the Artistic License version 2.0.
 
+These conditions apply for all files in this package.
+
+=head1 AUTHOR
+
+Renee Baecker <module@renee-baecker.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Renee Baecker.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
+
